package Alien::SDL;
use strict;
use warnings;

our $VERSION = '0.06';

=head1 NAME

Alien::SDL - building, finding and using SDL binaries

=head1 SYNOPSIS

    use Alien::SDL <options>;

    Just gets windows deps for strawberry perl

=head1 DESCRIPTION

Please see L<Alien> for the manifesto of the Alien namespace.

In short C<Alien::SDL> can be used to detect and get
configuration settings from an installed SDL and related libraries .
=cut

sub new
{
	my $self = shift;
}


#################### main pod documentation begin ###################
=head1 BUGS

Please post issues and bugs at http://github.com/kthakore/Alien_SDL/issues


=head1 SUPPORT



=head1 AUTHOR

    Kartik Thakore
    CPAN ID: KTHAKORE
    none
    Thakore.Kartik@gmail.com
    http://yapgh.blogspot.com

=head1 COPYRIGHT

This program is free software; you can redistribute
it and/or modify it under the same terms as Perl itself.

The full text of the license can be found in the
LICENSE file included with this module.


=head1 SEE ALSO

perl(1).

=cut

#################### main pod documentation end ###################


1;
# The preceding line will help the module return a true value

